==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Minden tma");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_UCOMMENT","Hozzszls");
define("_REVIEWS","Ismertetk");
define("_SEARCHUSERS","Keress a felhasznli adatbzisban");
define("_SEARCHSECTIONS","Keress a hosszabb rsokban");
define("_SEARCHREVIEWS","Keress az ismertetk kztt");
define("_SEARCHIN","Keress");
define("_ARTICLES","cikk");
define("_ALLAUTHORS","Minden szerz");
define("_ALL","Minden");
define("_WEEK","ht");
define("_WEEKS","ht");
define("_MONTH","hnap");
define("_MONTHS","hnap");
define("_SEARCHON","Miben akarsz keresni?");
define("_SSTORIES","Cikkek");
define("_SSECTIONS","rsok");
define("_SUSERS","Felhasznlk");
define("_NOMATCHES","A keress nem eredmnyezett tallatot");
define("_PREVMATCHES","elz tallat");
define("_NEXTMATCHES","kvetkez tallat");
define("_INSECTION","Cikk a kvetkez tmban:");
define("_NONAME","Nincs nv megadva");
define("_SCOMMENTS","Hozzszlsok");
define("_SEARCHRESULTS","Keress eredmnyei");
define("_CONTRIBUTEDBY","Bekldte:");
define("_UCOMMENTS","Hozzszlsok");
define("_MATCHTITLE","tallat cmre");
define("_MATCHTEXT","tallat cikk szvegre");
define("_MATCHBOTH","tallat cmre s szvegre");
define("_SREPLY","vlasz");
define("_SREPLIES","vlasz");
define("_ATTACHART","Csatolva a cikkhez");
define("_PAGES","oldal");
define("_REVIEWSCORE","Az ismertet osztlyozsa");
define("_PAGE","oldal");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Minden tma");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_UCOMMENT","Hozzszls");
define("_REVIEWS","Ismertetk");
define("_SEARCHUSERS","Keress a felhasznli adatbzisban");
define("_SEARCHSECTIONS","Keress a hosszabb rsokban");
define("_SEARCHREVIEWS","Keress az ismertetk kztt");
define("_SEARCHIN","Keress");
define("_ARTICLES","cikk");
define("_ALLAUTHORS","Minden szerz");
define("_ALL","Minden");
define("_WEEK","ht");
define("_WEEKS","ht");
define("_MONTH","hnap");
define("_MONTHS","hnap");
define("_SEARCHON","Miben akarsz keresni?");
define("_SSTORIES","Cikkek");
define("_SSECTIONS","rsok");
define("_SUSERS","Felhasznlk");
define("_NOMATCHES","A keress nem eredmnyezett tallatot");
define("_PREVMATCHES","elz tallat");
define("_NEXTMATCHES","kvetkez tallat");
define("_INSECTION","Cikk a kvetkez tmban:");
define("_NONAME","Nincs nv megadva");
define("_SCOMMENTS","Hozzszlsok");
define("_SEARCHRESULTS","Keress eredmnyei");
define("_CONTRIBUTEDBY","Bekldte:");
define("_UCOMMENTS","Hozzszlsok");
define("_MATCHTITLE","tallat cmre");
define("_MATCHTEXT","tallat cikk szvegre");
define("_MATCHBOTH","tallat cmre s szvegre");
define("_SREPLY","vlasz");
define("_SREPLIES","vlasz");
define("_ATTACHART","Csatolva a cikkhez");
define("_PAGES","oldal");
define("_REVIEWSCORE","Az ismertet osztlyozsa");
define("_PAGE","oldal");

?>
